@@ -1,23 +1,28 @@
 extern void *_activity_[];
 
-externvar id ProcessType;
 externvar id DefaultOrder;
+externvar id Activity;
 externvar id Action;
 externvar id ActionArgs;
+externvar id FAction;
+externvar id ActionTarget;
 externvar id ActionTo;
 externvar id ActionForEach;
+externvar id FActionForEach;
+externvar id FActionForEachHeterogeneous;
+externvar id FActionForEachHomogeneous;
 externvar id ActionCall;
+externvar id ActionChanged;
+externvar id FActionCreating;
 externvar id ActionCreatingCall;
 externvar id ActionCreatingTo;
 externvar id ActionCreatingForEach;
+externvar id FActionCreatingForEachHeterogeneous;
+externvar id FActionCreatingForEachHomogeneous;
 externvar id ActionCreating;
-externvar id Activity;
-externvar id ScheduleActivity;
-externvar id SwarmActivity;
-externvar id ForEachActivity;
+externvar id ActivityIndex;
 externvar id ActionType;
 externvar id SynchronizationType;
-externvar id SwarmProcess;
 externvar id AutoDrop;
 externvar id CompoundAction;
 externvar id ActionGroup;
@@ -26,6 +31,10 @@ externvar id RepeatInterval;
 externvar id ConcurrentGroupType;
 externvar id SingletonGroups;
 externvar id Schedule;
+externvar id ScheduleActivity;
+externvar id SwarmActivity;
+externvar id ForEachActivity;
+externvar id SwarmProcess;
 externvar id GetSubactivityAction;
 externvar id ConcurrentGroup;
 externvar id ConcurrentSchedule;
