@@ -13,8 +13,9 @@ extern jclass c_Boolean,
   c_Long, c_Float,
   c_Class, c_Field, c_Method, c_Selector,
   c_Object, c_String, 
-  c_Double, c_PhaseCImpl,
-  c_SwarmEnvironment;
+  c_Double, c_PhaseCImpl, c_Primitives,
+  c_SwarmEnvironment, c_Collection,
+  c_Modifier;
 
 extern jmethodID m_BooleanValueOf,
   m_ByteValueOf, 
@@ -32,10 +33,13 @@ extern jmethodID m_BooleanValueOf,
   m_ClassGetDeclaredField,
   m_ClassGetDeclaredFields,
   m_ClassGetDeclaredMethods,
+  m_ClassGetFields,
   m_ClassGetName,
+  m_ClassIsArray,
   m_FieldGetType,
   m_FieldGetBoolean,
   m_FieldGetChar,
+  m_FieldGetShort,
   m_FieldGetInt,
   m_FieldGetLong,
   m_FieldGetFloat,
@@ -43,10 +47,15 @@ extern jmethodID m_BooleanValueOf,
   m_FieldGetObject,
   m_FieldGetName,
   m_MethodGetName,
+  m_MethodGetReturnType,
+  m_MethodGetModifiers,
+  m_ModifierIsPublic,
+  m_ModifierIsStatic,
   m_SelectorConstructor,
   m_HashCode,
   m_Equals,
-  m_PhaseCImpl_copy_creating_phase_to_using_phase;
+  m_PhaseCImpl_copy_creating_phase_to_using_phase,
+  m_PrimitivesGetTypeMethod;
 
 extern jfieldID f_nameFid,
   f_retTypeFid,
